/**************************************************************************
**   File: connect.c
**
**   Description:
**
**   Example program for getting connection information.
**
**   This program demonstrates how to get connection information for all
**   current server connections.
**
**
**   DISCLAIMER  
**  
**   Novell, Inc. makes no representations or warranties with respect to
**   any NetWare software, and specifically disclaims any express or
**   implied warranties of merchantability, title, or fitness for a
**   particular purpose.  
**
**   Distribution of any NetWare software is forbidden without the
**   express written consent of Novell, Inc.  Further, Novell reserves
**   the right to discontinue distribution of any NetWare software.
**   
**   Novell is not responsible for lost profits or revenue, loss of use
**   of the software, loss of data, costs of re-creating lost data, the
**   cost of any substitute equipment or program, or claims by any party
**   other than you.  Novell strongly recommends a backup be made before
**   any software is installed.   Technical support for this software
**   may be provided at the discretion of Novell.
**
**	  QMK386 options used:
**
**	  None
**
**   Programmers:
**
**   Ini   Who                  Firm
**   ---------------------------------------------------------------------
**   KDB   Kevin Burnett        Novell Developer Support
**
**
**   History:
**
**   When        Who      What
**   ---------------------------------------------------------------------
**   1-18-1996   KDB      First code.
**
*/


/**************************************************************************
** Compiler setup.
*/
	/*----------------------------------------------------------------------
	** ANSI
	*/
	#include <process.h>	/*	ThreadSwitchWithDelay(), GetThreadGroupID(),
                          SetThreadGroupID() */
	#include <conio.h>	/* SetAutoScreenDestructionMode(),
									SetCtrlCharCheckMode(), getch(), ungetch() */
	#include <signal.h>	/* signal() */
	#include <errno.h>	/* Symbol 'ESUCCESS'*/
	#include <stdio.h>	/* printf() */

	/*----------------------------------------------------------------------
	** NetWare
	*/
	#include <nwconn.h>	/* GetMaximumNumberOfStations(),
									GetConnectionInformation() */
	#include <nwmisc.h>	/* LongSwap() */

/**************************************************************************
** Global variables
*/
	int	NLM_exiting = FALSE;
	int   NLM_threadCnt= 0;
	int	NLM_mainThreadGroupID;
	int	oldThreadGroupID;
	int	ccode;

/**************************************************************************
** NLM Signal Handler.
*/
void NLM_SignalHandler(int sig)
  {
  int oldThreadGroupID;

  switch(sig)
		{
		case SIGTERM:
			NLM_exiting = TRUE;
			oldThreadGroupID=SetThreadGroupID(NLM_mainThreadGroupID);
			ungetch(13);
			SetThreadGroupID(oldThreadGroupID);
			while(NLM_threadCnt != 0)
   			ThreadSwitchWithDelay();
			break;

		default:
   		break;
		}

  return;
  }

/**************************************************************************
** main procedure
*/

void main(void)
	{
 
	int	i;
	int	maxConnections;
	char	objectName[255];
	WORD	objectType;
	long	objectID;
	long	swappedObjectID;
	BYTE	loginTime[7];

	++NLM_threadCnt;

	/*----------------------------------------------------------------------
	** No final "Press a key" message when unloading.
	*/
	SetAutoScreenDestructionMode(TRUE);

	/*----------------------------------------------------------------------
	** Disable CTRL-S and CTRL-C.
	*/
	SetCtrlCharCheckMode(FALSE);

	/*----------------------------------------------------------------------
	** Get the current thread group ID.
	*/
	NLM_mainThreadGroupID=GetThreadGroupID();

	/*----------------------------------------------------------------------
	** Register SIGTERM & SIGINT handler.
	*/
	signal(SIGTERM, NLM_SignalHandler);

	/*----------------------------------------------------------------------
	** Determine how many active connectionsthe server has and print it out.
	*/
	maxConnections = GetMaximumNumberOfStations();
	printf("\nMaximum Connections = %d\n", maxConnections);

	/*----------------------------------------------------------------------
	** Get information for each connection and print it out.
	*/
	for (i=0; i < maxConnections; i++)
		{
		if(NLM_exiting == TRUE)
			break;

		ccode = GetConnectionInformation(
			/* I- connection Number */	i,
			/* -O object Name       */	objectName,
			/* -O object Type       */	&objectType,
			/* -O object ID         */	&objectID,
			/* -O login Time        */	loginTime
			);

		if(ccode != ESUCCESS)
			{
			printf("ERROR: GetConnectionInformationk() reports %d\n", ccode);
   		goto END_ERR;
			}
		
		printf("\nConnection Number = %d\n", i);
		printf("Object Name = %s\n", objectName);
		printf("Object Type = %d : ",objectType);
		
		switch (objectType)
			{
			case 0:
				printf("unknown\n");
				break;
			case 1:
				printf("user\n");
				break;
			case 2:
				printf("group\n");
				break;
			case 3:
				printf("print queue\n");
				break;
			case 4:
				printf("file server\n");
				break;
			case 5:
				printf("job server\n");
				break;
			case 6:
				printf("gateway\n");
				break;
			case 7:
				printf("print server\n");
				break;
			case 8:
				printf("archive queue\n");
				break;
			case 9:
				printf("archive server\n");
				break;
			case 10:
				printf("job queue\n");
				break;
			case 11:
				printf("administration\n");
				break;
			default:
				printf("type is not in the database of this program.\n");
			}
				
		swappedObjectID = LongSwap(objectID);
		printf("Object ID = %ld", swappedObjectID);
		if (objectID == 0)
			printf(" : unused logical connection number\n");
		else
			printf("\n");

		if ((objectType != 0) && (objectID != 0))
			{
			printf("Login Date = %d/%d/%d\n", loginTime[1], loginTime[2],
						loginTime[0]);
			printf("Login Time = %d:%d:%d\n", loginTime[3], loginTime[4],
						loginTime[5]);
			switch (loginTime[6])
				{
				case 0:
					printf("Login Day: Sunday\n");
					break;
				case 1:
					printf("Login Day: Monday\n");
					break;
				case 2:
					printf("Login Day: Tuesday\n");
					break;
				case 3:
					printf("Login Day: Wednesday\n");
					break;
				case 4:
					printf("Login Day: Thursday\n");
					break;
				case 5:
					printf("Login Day: Friday\n");
					break;
				case 6:
					printf("Login Day: Saturday\n");
					break;
				default:
					printf("Invalid day\n");
					break;
				}
			}

		printf("\n");

	/*----------------------------------------------------------------------
	** Pause after each screen of connection information.
	*/
		getch();
		}

END_ERR:

	--NLM_threadCnt;

	return;
	}
/****************************************************************************/
/****************************************************************************/

